==> haskell-murmur-hash-0.1.0.10-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 murmur-hash
version:              0.1.0.10
visibility:           public
id:                   murmur-hash-0.1.0.10-J20lvSjBF1rKaV9347DkX6
key:                  murmur-hash-0.1.0.10-J20lvSjBF1rKaV9347DkX6
license:              BSD-3-Clause
maintainer:           Thomas Schilling <nominolo@googlemail.com>
author:               Thomas Schilling
stability:            provisional
homepage:             http://github.com/nominolo/murmur-hash
synopsis:             MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.

    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.

category:             Data, Digest
abi:                  939c2b8f85b66f9229ab10dacbd19838
exposed:              True
exposed-modules:      Data.Digest.Murmur32 Data.Digest.Murmur64
import-dirs:          /usr/lib/ghc-9.2.8/site-local/murmur-hash-0.1.0.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/murmur-hash-0.1.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-murmur-hash
hs-libraries:         HSmurmur-hash-0.1.0.10-J20lvSjBF1rKaV9347DkX6
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:   /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html:         /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-murmur-hash-0.1.0.11-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 murmur-hash
version:              0.1.0.11
visibility:           public
id:                   murmur-hash-0.1.0.11-Ha47ENwd5Kw35sH8NFYP5I
key:                  murmur-hash-0.1.0.11-Ha47ENwd5Kw35sH8NFYP5I
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Thomas Schilling
stability:            provisional
homepage:             https://github.com/nominolo/murmur-hash
synopsis:             MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.

    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.

category:             Data, Digest
abi:                  cd25adfebe1f455cc58ba9cdeab2dbf6
exposed:              True
exposed-modules:      Data.Digest.Murmur32 Data.Digest.Murmur64
import-dirs:          /usr/lib/ghc-9.2.8/site-local/murmur-hash-0.1.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/murmur-hash-0.1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-murmur-hash
hs-libraries:         HSmurmur-hash-0.1.0.11-Ha47ENwd5Kw35sH8NFYP5I
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:   /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html:         /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
